==========================
DevStack plugin for Calico
==========================

Welcome to networking-calico's DevStack plugin!  For how to use this, please
see
http://docs.projectcalico.org/master/getting-started/openstack/installation/devstack.
